@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -33,10 +33,6 @@ extern "C" {
  *
  */
 
-DWORD WINAPI Task_ThreadProc (PVOID lp);
-
-void Task_Perform (LPTASKPACKET ptp);
-
 void Task_OpenCell (LPTASKPACKET ptp);
 void Task_UpdCreds (LPTASKPACKET ptp);
 void Task_UpdUsers (LPTASKPACKET ptp);
@@ -303,7 +299,7 @@ void Task_OpenCell (LPTASKPACKET ptp)
 
    // Try to open the cell for administration
    //
-   ptp->rc = asc_CellOpen (g.idClient, lpp->hCreds, lpp->szCell, AFSADMSVR_SCOPE_USERS, &TASKDATA(ptp)->idCell, &ptp->status);
+   ptp->rc = asc_CellOpen (g.idClient, (PVOID)lpp->hCreds, lpp->szCell, AFSADMSVR_SCOPE_USERS, &TASKDATA(ptp)->idCell, &ptp->status);
 
    if (ptp->rc)
       {
@@ -372,7 +368,7 @@ void Task_UpdCreds (LPTASKPACKET ptp)
 
    // Tell the admin server to use our new credentials, and refresh everything
    //
-   if (!asc_CredentialsPush (g.idClient, g.hCreds, g.idCell, &ptp->status))
+   if (!asc_CredentialsPush (g.idClient, (PVOID)g.hCreds, g.idCell, &ptp->status))
       ptp->rc = FALSE;
    else
       ptp->rc = PerformRefresh (ptp, g.idCell, &ptp->status);
@@ -629,7 +625,8 @@ BOOL Task_User_GroupList_Set_Do (LPUSER_GROUPLIST_SET_PARAMS lpp, ULONG *pStatus
    // test it for inclusion of a particular group.
    //
    LPHASHLIST pGroupsAllow = New (HASHLIST);
-   for (size_t iGroup = 0; iGroup < lpp->pGroups->cEntries; ++iGroup)
+   size_t iGroup;
+   for (iGroup = 0; iGroup < lpp->pGroups->cEntries; ++iGroup)
       pGroupsAllow->AddUnique ((PVOID)(lpp->pGroups->aEntries[ iGroup ].idObject));
 
    // We'll have to do this next bit for each user in the supplied user-list
@@ -1186,7 +1183,8 @@ BOOL Task_Group_Members_Set_Do (LPGROUP_MEMBERS_SET_PARAMS lpp, ULONG *pStatus)
    // test it to see if a particular member should remain in a group.
    //
    LPHASHLIST pMembersAllow = New (HASHLIST);
-   for (size_t iMember = 0; iMember < lpp->pMembers->cEntries; ++iMember)
+   size_t iMember;
+   for (iMember = 0; iMember < lpp->pMembers->cEntries; ++iMember)
       pMembersAllow->AddUnique ((PVOID)(lpp->pMembers->aEntries[ iMember ].idObject));
 
    // We'll have to do this next bit for each group in the supplied group-list
@@ -1361,7 +1359,8 @@ BOOL Task_Group_Owned_Set_Do (LPGROUP_OWNED_SET_PARAMS lpp, ULONG *pStatus)
    // quickly test it for inclusion of a particular group.
    //
    LPHASHLIST pGroupsAllow = New (HASHLIST);
-   for (size_t iGroup = 0; iGroup < lpp->pOwnedGroups->cEntries; ++iGroup)
+   size_t iGroup;
+   for (iGroup = 0; iGroup < lpp->pOwnedGroups->cEntries; ++iGroup)
       pGroupsAllow->AddUnique ((PVOID)(lpp->pOwnedGroups->aEntries[ iGroup ].idObject));
 
    // Obtain the current list-of-groups-owned for this group
@@ -1489,7 +1488,7 @@ void Task_Group_Create (LPTASKPACKET ptp)
 
       AFSADMSVR_CREATEGROUP_PARAMS pp;
       memset (&pp, 0x00, sizeof(AFSADMSVR_CREATEGROUP_PARAMS));
-      pp.idGroup = lpp->idGroup;
+      pp.idGroup = (int) lpp->idGroup;
       lstrcpy (pp.szName, pszName);
       lstrcpy (pp.szOwner, lpp->szOwner);
       if (!pp.szOwner[0])
