@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -60,33 +60,33 @@ END_MESSAGE_MAP()
 /////////////////////////////////////////////////////////////////////////////
 // CPartitionInfoDlg message handlers
 
-BOOL CPartitionInfoDlg::OnInitDialog() 
+BOOL CPartitionInfoDlg::OnInitDialog()
 {
     double percentUsed;     // because partition sizes are big
 
 	CDialog::OnInitDialog();
-	
+
 	ASSERT(m_nSize != 0);
 
 	CString strSize;
 	strSize.Format(_T("%ld"), m_nSize);
-	
+
 	CString strFree;
 	strFree.Format(_T("%ld"), m_nFree);
-	
+
 	CString strPerUsed;
-	strPerUsed.Format(_T("%d"), ((m_nSize - m_nFree) * 100) / m_nSize);
+	strPerUsed.Format(_T("%d"), ((m_nSize - m_nFree) / m_nSize) * 100);
 
 	m_Size.SetWindowText(strSize);
 	m_Free.SetWindowText(strFree);
-    percentUsed = ( double(m_nSize - m_nFree) * 100.0l ) / double(m_nSize);
+    percentUsed = ( double(m_nSize - m_nFree) / double(m_nSize) * 100.0l);
     strPerUsed.Format(_T("%2.2lf"), percentUsed );
 
 	return TRUE;  // return TRUE unless you set the focus to a control
 	              // EXCEPTION: OCX Property Pages should return FALSE
 }
 
-void CPartitionInfoDlg::OnHelp() 
+void CPartitionInfoDlg::OnHelp()
 {
 	ShowHelp(m_hWnd, PARTITION_INFO_HELP_ID);
 }
