@@ -300,20 +300,17 @@ _afsconf_InitKeys(struct afsconf_dir *dir)
  * in the original KeyFile, so that we can continue to be compatible with
  * utilities that directly modify that file.
  *
- * All other keys are stored in the file KeyFileEx, which has the following
+ * All other keys are stored in the file KeyFileExt, which has the following
  * format:
  *    0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2
  *   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
- *   |                        version number                           |
- *   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  *   |                        number of keys                           |
  *   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  *   | Key data ...
  *   +-+-+-+-+-+-+-+
  *
- * The version number is 1 at present. Version numbers higher than 1
- * indicate a keyfile that is not backwards compatible with this
- * specification.
+ * If the format ever needs to chanage incompatibly, a new file name
+ * will be used.
  *
  * Key data is a sequence of the following records (note that these are
  * not word aligned - the next record begins where the previous one ends)
@@ -365,6 +362,8 @@ _parseOriginalKeyFile(struct afsconf_dir *dir, char *fileName)
     for(i=0; i<nkeys; i++) {
 
 	key = afsconf_typedKey_blank();
+	if (key == NULL)
+	    goto fail;
 
 	key->type = afsconf_rxkad;
 	key->subType = 0;
@@ -473,6 +472,8 @@ _parseExtendedKeyFile(struct afsconf_dir *dir, char *fileName)
 	afs_int32 reclen;
 
 	key = afsconf_typedKey_blank();
+	if (key == NULL)
+	    goto fail;
 
 	/* The only data version we currently parse has a reclen of 16.
 	 * Anything smaller indicates a corrupt key file. Anything more,
@@ -518,7 +519,6 @@ _parseExtendedKeyFile(struct afsconf_dir *dir, char *fileName)
 	code = read(fd, key->key.val, reclen);
 	if (code != reclen) {
 	    rx_opaque_freeContents(&key->key);
-	    free(key);
 	    goto fail;
 	}
 	code = addMemoryKey(dir, key, 1);
@@ -821,6 +821,39 @@ out:
     return code;
 }
 
+int
+_afsconf_CountKeys(struct afsconf_dir *dir)
+{
+    int count = 0;
+    struct opr_queue *typeCursor;
+    struct keyTypeList *typeEntry;
+    struct opr_queue *kvnoCursor;
+    struct kvnoList *kvnoEntry;
+    struct opr_queue *subCursor;
+
+    for (opr_queue_Scan(&dir->keyList, typeCursor)) {
+	typeEntry = opr_queue_Entry(typeCursor, struct keyTypeList, link);
+	for (opr_queue_Scan(&typeEntry->kvnoList, kvnoCursor)) {
+	    kvnoEntry = opr_queue_Entry(kvnoCursor, struct kvnoList, link);
+	    for (opr_queue_Scan(&kvnoEntry->subTypeList, subCursor))
+		count++;
+	}
+    }
+    return count;
+}
+
+int
+afsconf_CountKeys(struct afsconf_dir *dir)
+{
+    int count = 0;
+
+    LOCK_GLOBAL_MUTEX;
+    count = _afsconf_CountKeys(dir);
+    UNLOCK_GLOBAL_MUTEX;
+
+    return count;
+}
+
 int
 afsconf_GetAllKeys(struct afsconf_dir *dir, struct afsconf_typedKeyList **keys)
 {
@@ -840,18 +873,8 @@ afsconf_GetAllKeys(struct afsconf_dir *dir, struct afsconf_typedKeyList **keys)
     if (code)
 	goto out;
 
-    count = 0;
     /* First, work out how many keys we have in total */
-    for (opr_queue_Scan(&dir->keyList, typeCursor)) {
-	typeEntry = opr_queue_Entry(typeCursor, struct keyTypeList, link);
-	for (opr_queue_Scan(&typeEntry->kvnoList, kvnoCursor)) {
-	    kvnoEntry = opr_queue_Entry(kvnoCursor, struct kvnoList, link);
-	    for (opr_queue_Scan(&kvnoEntry->subTypeList, subCursor)) {
-		subEntry = opr_queue_Entry(subCursor, struct subTypeList, link);
-		count++;
-	    }
-	}
-    }
+    count = _afsconf_CountKeys(dir);
 
     /* Allocate space for all of these */
     retval = malloc(sizeof(struct afsconf_typedKeyList));
@@ -932,7 +955,7 @@ pickBestKvno(struct afsconf_dir *dir, afsconf_keyType type)
     /* Except, if we're in the rxkad list, we might have a bcrypt entry that
      * has a kvno of 999. So we need to skip that one
      */
-    while (type == afsconf_rxgk && kvnoEntry->kvno == 999) {
+    while (type == afsconf_rxkad && kvnoEntry->kvno == 999) {
 	kvnoEntry = opr_queue_Prev(&typeEntry->kvnoList, struct kvnoList,
 				   link);
 	if (opr_queue_IsEnd(&typeEntry->kvnoList, &kvnoEntry->link))
@@ -1059,6 +1082,8 @@ afsconf_typedKey_new(afsconf_keyType type, int kvno, int subType,
 void
 afsconf_typedKey_free(struct afsconf_typedKey **key)
 {
+    if (*key == NULL)
+	return;
     rx_opaque_freeContents(&(*key)->key);
     free(*key);
     *key = NULL;
@@ -1084,10 +1109,14 @@ void
 afsconf_typedKey_values(struct afsconf_typedKey *key, afsconf_keyType *type,
 			int *kvno, int *subType, struct rx_opaque **material)
 {
-    *type = key->type;
-    *kvno = key->kvno;
-    *subType = key->subType;
-    *material = &key->key;
+    if (type != NULL)
+	*type = key->type;
+    if (kvno != NULL)
+	*kvno = key->kvno;
+    if (subType != NULL)
+	*subType = key->subType;
+    if (material != NULL)
+	*material = &key->key;
 }
 
 int
